Exception Objects — Alembic 1.18.2 documentation

Skip to main content
`Ctrl`+`K`

# Exception Objects

exception alembic.util.exc.AutogenerateDiffsDetected(message: str, revision_context: RevisionContext, diffs: List[Tuple[Any, ...]])

  Raised when diffs were detected by the `command.check()` command.

  Added in version 1.9.0.

exception alembic.util.exc.CommandError

  Base command error for all exceptions

exception alembic.util.exc.DatabaseNotAtHead

  Indicates the database is not at current head revisions.

  Raised by the `command.current()` command when the `command.current.check_heads` parameter is used.

  Added in version 1.17.1.